# Filter Options
**Note:** More can be found on craigslist, I only list the main ones and some relating to cars

### Section Options 
**Note:** More can be found simply be going to Craigslist.

```
'sss' (all) 
'cta' (cars all) 
'cto' (cars owner) 
'syp' (computer parts) 
'sya' (computers) 
'ela' (electronics) 
'zip' (free stuff) 
```

### Default Filters
```
'&postedToday=1' (to minimize clutter)
```

### Price
```
'&min_price=' (enter price after '=')
'&max_price=' (enter price after '=')
```

### Condition
```
'&condition=10' (new)
'&condition=20' (like new)
'&condition=30' (excellent)
'&condition=40' (good)
'&condition=50' (fair)
'&condition=60' (salvage)
```

### Transmission: 

```
'&auto_transmission=2' (automatic)
'&auto_transmission=1' (manual)
'&auto_transmission=3' (other)
```

### Type:

```
'&auto_bodytype=1' (bus)
'&auto_bodytype=2' (convertible)
'&auto_bodytype=3' (coupe)
'&auto_bodytype=4' (hatchback)
'&auto_bodytype=5' (mini-van)
'&auto_bodytype=6' (offroad)
'&auto_bodytype=7' (pickip)
'&auto_bodytype=8' (sedan)
'&auto_bodytype=9' (truck)
'&auto_bodytype=10' (SUV)
'&auto_bodytype=11' (wagon)
'&auto_bodytype=12' (van)
'&auto_bodytype=13' (other)
```

### Title Status: 

```
'&auto_title_status=1' (clean)
'&auto_title_status=2' (salvage)
'&auto_title_status=3' (rebuild)
'&auto_title_status=4' (parts only)
'&auto_title_status=5' (lien)
'&auto_title_status=6' (missing)
```
